(define-module (ui ldap-groups ajax)
    :use-module (alterator woo)
    :use-module (alterator ajax)
    :export (init))

(define (update-groups . data)
    (let ((group (if (pair? data) (car data) (form-value "group"))))
    (form-update-value "groupname" group)
    (form-update-value-list '("groupmail") (woo-read-first "/ldap-groups" 'group group))
    (update-users-list)))

(define (update-users-list)
    (let ((group (form-value "group")))
    (form-update-enum "usersin" (woo-list "/ldap-groups/users_in" 'group group))
    (form-update-enum "usersout" (woo-list "/ldap-groups/users_out" 'group group))))

(define (ui-init . data)
    (form-update-value "newgroupname" "")
    (form-update-value "groupname" "")
    (form-update-enum "group" (woo-list "/ldap-groups/avail_groups"))
    (update-groups data))

(define (ui-groupsave)
    (let ((group (form-value "group")))
    (if  (not (boolean? group))
      (catch/message
        (lambda()
        (woo-write "/ldap-groups" 'group group 'groupmail (form-value "groupmail"))
        (ui-init))))))

(define (ui-groupdel)
    (let ((group (form-value "group")))
      (if  (not (boolean? group))
      (catch/message
        (lambda()
        (woo-delete "/ldap-groups" 'group group 'language (form-value "language"))
        (ui-init))))))

(define (ui-groupadd)
    (let ((newgroupname (form-value "newgroupname")))
      (catch/message
        (lambda()
        (woo-new "/ldap-groups" 'newgroupname newgroupname 'language (form-value "language"))
        (ui-init newgroupname)))))

(define (ui-useradd)
    (let ((group (form-value "group"))
          (usersout (form-value "usersout")))
    (if (and (not (boolean? group)) (not (boolean? usersout)))
    (woo "useradd" "/ldap-groups" 'group group 'usersout usersout))
    (update-users-list)))


(define (ui-userdel)
    (let ((group (form-value "group"))
          (usersin (form-value "usersin")))
    (if (and (not (boolean? group)) (not (boolean? usersin)))
    (woo "userdel" "/ldap-groups" 'group group 'usersin usersin))
    (update-users-list)))

(define (init)
    (ui-init)
    (form-bind "useradd" "click" ui-useradd)
    (form-bind "userdel" "click" ui-userdel)
    (form-bind "groupsave" "click" ui-groupsave)
    (form-bind "groupadd" "click" ui-groupadd)
    (form-bind "groupdelete" "click" ui-groupdel)
    (form-bind "group" "change" update-groups))

